@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.80 copyleft GPL Pollo (magura@ardilla.dyndns.org) y Presi (presi@confluencia.net)
+# FitGallery 0.81 copyleft GPL Pollo (magura@ardilla.dyndns.org) y Presi (presi@confluencia.net)
 # http://fitgallery.presi.org
 
 # thumb generator file
@@ -8,7 +8,7 @@
 function thumbnail ($galeria,$valor,$horiz,$tipo)
 {
 
-include 'config-dirgal.php';
+include 'config/config-thumb.php';
 
 $dg=$dirgal."/".basename($galeria);
 switch ($tipo)
@@ -27,6 +27,8 @@ else
   $rutaimgs=$dg."/"."imgs";
   $imagen=$rutaimgs."/".$fichero;
 
+  if ($horiz>$limite_horiz) $horiz=$limite_horiz;
+
   $size=getimagesize("$imagen");
   $new_w=$horiz*$size[0]/$size[1];
   $new_h=$horiz;
